==> nextcloud-app-deck-1%3a1.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/pt_PT.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Baralho",
    "Personal" : "Pessoal",
    "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" chegou a sua data de vencimento",
    "The board \"%s\" has been shared with you by %s." : "O quadro \"%s\" foi partilhado consigo por %s.",
    "{user} has shared the board %s with you." : "{user} partilhou o quadro %s consigo.",
    "Finished" : "Terminado",
    "To review" : "A rever",
    "Action needed" : "Acção necessária",
    "Later" : "Mais tarde",
    "copy" : "copiar",
    "Done" : "Concluído",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
    "No file was uploaded" : "O ficheiro foi carregado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Create new board" : "Criar novo quadro",
    "Cancel" : "Cancelar",
    "File already exists" : "O ficheiro já existe",
    "Show archived cards" : "Mostrar cartões arquivados",
    "Details" : "Detalhes",
    "Sharing" : "Partilha",
    "Tags" : "Etiquetas",
    "Undo" : "Desfazer",
    "(Group)" : "(Grupo)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Apagar",
    "Add a new stack" : "Adicionar nova pilha",
    "Add card" : "Adicionar um cartão",
    "Edit" : "Editar",
    "Title" : "Título",
    "Members" : "Membros",
    "Due date" : "Data limite",
    "Description" : "Descrição",
    "Attachments" : "Anexos",
    "Comments" : "Comentários",
    "Modified" : "Modificado",
    "Created" : "Criado",
    "Save" : "Guardar",
    "Reply" : "Resposta",
    "Update" : "Atualizar",
    "(group)" : "(grupo)",
    "seconds ago" : "segundos atrás",
    "Delete card" : "Eliminar cartão",
    "Archived boards" : "Quadros arquivados",
    "Settings" : "Definições",
    "New board title" : "Novo título de quadro",
    "Share" : "Partilhar",
    "Edit board" : "Editar quadro",
    "An error occurred" : "Ocorreu um erro",
    "Archive board" : "Arquivar quadro",
    "Delete board" : "Eliminar quadro",
    "Board details" : "Detalhes do quadro"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3a1.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/pt_PT.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Baralho",
    "Personal" : "Pessoal",
    "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" chegou a sua data de vencimento",
    "The board \"%s\" has been shared with you by %s." : "O quadro \"%s\" foi partilhado consigo por %s.",
    "{user} has shared the board %s with you." : "{user} partilhou o quadro %s consigo.",
    "Finished" : "Terminado",
    "To review" : "A rever",
    "Action needed" : "Acção necessária",
    "Later" : "Mais tarde",
    "copy" : "copiar",
    "Done" : "Concluído",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a directiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excedo a directiva MAX_FILE_SIZE especificada no formulário HTML",
    "No file was uploaded" : "O ficheiro foi carregado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Add board" : "Arquivar cartão",
    "Cancel" : "Cancelar",
    "File already exists" : "O ficheiro já existe",
    "Hide archived cards" : "Esconder cartões arquivados",
    "Show archived cards" : "Mostrar cartões arquivados",
    "Details" : "Detalhes",
    "Sharing" : "Partilha",
    "Tags" : "Etiquetas",
    "Undo" : "Desfazer",
    "(Group)" : "(Grupo)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Apagar",
    "Add card" : "Adicionar um cartão",
    "Edit" : "Editar",
    "Title" : "Título",
    "Members" : "Membros",
    "Due date" : "Data limite",
    "Description" : "Descrição",
    "Attachments" : "Anexos",
    "Comments" : "Comentários",
    "Select Date" : "Escolha a data",
    "Modified" : "Modificado",
    "Created" : "Criado",
    "Save" : "Guardar",
    "Reply" : "Resposta",
    "Update" : "Atualizar",
    "(group)" : "(grupo)",
    "Archive card" : "Arquivar cartão",
    "Delete card" : "Eliminar cartão",
    "seconds ago" : "segundos atrás",
    "Archived boards" : "Quadros arquivados",
    "Shared with you" : "Shared with you",
    "Edit board" : "Editar quadro",
    "Board details" : "Detalhes do quadro",
    "An error occurred" : "Ocorreu um erro",
    "Today" : "Hoje",
    "Tomorrow" : "Amanhã",
    "This week" : "Esta semana"
},
"nplurals=2; plural=(n != 1);");
